﻿--[[
	This file is part of PlayerZone AddOn for WoW 3.3.5a

	This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

	Copyright © 2017 Yulemath
]]

local PlayerZone = LibStub("AceAddon-3.0"):GetAddon("PlayerZone")
local L = LibStub("AceLocale-3.0"):GetLocale("PlayerZone")

function PlayerZone:GetZoneLevel()
	local map, levelDB, zone = GetMapInfo(), PlayerZoneData.level, {}
		levelDB.pvp = 3 -- Set pvp variable to 3, then, if the player is not in a region (for exemple when he is on a traveling boat), the frame will be hidden and colored
	local i = string.lower(map)
	zone = {

	--[[ Table Usage : {"zonename",levelmin,levelmax,pvpflag,cityflag}
	- "zonename" : Name of the current region (must be in lower case)
	- levelmin : Number for minimum level of the region
	- levelmax : Number for maximum level of the region
	- pvpflag : Determine the pvp type :0 = contested, 1 = Alliance, 2 = Horde
	- cityflag : Determine if region is a city or not (bool)]]
	
	-- Kalimdor
   {"teldrassil",1,10,1,0},
   {"azuremystisle",1,10,1,0},
   {"bloodmystisle",20,30,1,0},
   {"darkshore",10,20,1,0},
   {"felwood",48,55,0,0},
   {"moonglade",10,70,0,0},
   {"winterspring",55,60,0,0},
   {"aszhara",45,55,0,0},
   {"durotar",1,10,2,0},
   {"barrens",10,20,2,0},
   {"ashenvale",18,30,0,0},
   {"stonetalonmountains",15,27,0,0},
   {"mulgore",1,10,2,0},
   {"desolace",30,40,0,0},
   {"feralas",45,50,0,0},
   {"dustwallow",35,45,0,0},
   {"thousandneedles",25,35,0,0},
   {"tanaris",40,50,0,0},
   {"ungorocrater",48,55,0,0},
   {"silithus",55,60,0,0},
   {"darnassis",0,0,1,1},
   {"theexodar",0,0,1,1},
   {"ogrimmar",0,0,2,1},
   {"thunderbluff",0,0,2,1},
   -- Eastern Kingdoms
   {"sunwell",68,70,0,0},
   {"eversongwoods",1,10,2,0},
   {"ghostlands",10,20,2,0},
   {"easternplaguelands",53,60,0,0},
   {"westernplaguelands",51,58,0,0},
   {"tirisfal",1,10,2,0},
   {"silverpine",10,20,2,0},
   {"hilsbrad",20,30,0,0},
   {"alterac",25,40,0,0},
   {"arathi",30,40,0,0},
   {"hinterlands",40,50,0,0},
   {"wetlands",20,30,0,0},
   {"lochmodan",10,20,1,0},
   {"dunmorogh",1,10,1,0},
   {"badlands",35,45,0,0},
   {"searinggorge",43,50,0,0},
   {"burningsteppes",50,58,0,0},
   {"redridge",15,20,0,0},
   {"elwynn",1,10,1,0},
   {"westfall",10,20,1,0},
   {"duskwood",18,30,0,0},
   {"deadwindpass",55,60,0,0},
   {"swampofsorrows",35,45,0,0},
   {"blastedlands",45,55,0,0},
   {"stranglethorn",30,45,0,0},
   {"silvermooncity",0,0,2,1},
   {"undercity",0,0,2,1},
   {"ironforge",0,0,1,1},
   {"stormwind",0,0,1,1},
   -- Outland
   {"shattrathcity",0,0,0,1},
   {"hellfire",58,63,0,0},
   {"terokkarforest",62,65,0,0},
   {"shadowmoonvalley",67,70,0,0},
   {"nagrand",64,67,0,0},
   {"zangarmarsh",60,64,0,0},
   {"bladesedgemountains",65,68,0,0},
   {"expansion01",0,0,3,0},
   {"netherstorm",65,68,0,0},
   -- Northend
   {"dalaran",0,0,0,1},
   {"crystalsongforest",77,80,0,0},
   {"icecrownglacier",77,80,0,0},
   {"sholazarbasin",76,78,0,0},
   {"lakewintergrasp",77,80,0,0},
   {"boreantundra",68,72,0,0},
   {"dragonblight",71,74,0,0},
   {"howlingfjord",68,72,0,0},
   {"grizzlyhills",73,75,0,0},
   {"zuldrak",74,77,0,0},
   {"thestormpeaks",77,80,0,0},
   {"hrothgarslanding",77,80,0,0}
}

for k, v in pairs(zone) do
	if ( v[1] == i ) then -- matching current region name with the table, if done then do next
		if ( v[5] == 1 ) then -- determine if cityflag on, if it is, set the variable 'text' to "city"
			levelDB.text = "City"
		else
			levelDB.text = v[2].." - "..v[3] -- Concatenate levelmin and levelmax for show the text correctly
		end
			levelDB.low = v[2]	-- Then, let's set the last variables
			levelDB.high = v[3]
			levelDB.pvp = v[4]
			if ( levelDB.pvp == 3 ) then PlayerZoneLevelFrame:Hide() else PlayerZoneLevelFrame:Show() end -- hidding frame for some region with pvpflag 3 (nether distorded)
		break -- break when finish
	end
	levelDB.text = i -- Little code for show me non yet included zones :)
end
zone = nil
end

function PlayerZone:FrameUpdate(text, low, high, pvp)
	PlayerZoneLevelText:SetText(text)
	self:LevelColor(high, low, text)
	self:TextColor(pvp)
	self:SetFrameSize()
end

function PlayerZone:LevelColor(lvlMax, lvlMin, text)
	
	local player, lvlLess, lvlFS = UnitLevel("player"), (lvlMax + 2), PlayerZoneLevelText	
	if ( player >= lvlLess ) then
		lvlFS:SetTextColor(0.4, 0.4, 0.4)
	elseif ( player >= lvlMax and player < lvlLess ) then
		lvlFS:SetTextColor(0, 1, 0)
	elseif ( player < lvlMax and player > lvlMin ) then
		lvlFS:SetTextColor(1, 1, 0)
	elseif ( player == lvlMin ) then
		lvlFS:SetTextColor(1, 0.3, 0.3)
	elseif ( player < lvlMin ) then
		lvlFS:SetTextColor(0.7, 0, 0)
	elseif ( text == "City" ) then
		lvlFS:SetText(L["Capitale"])
		lvlFS:SetTextColor(0, 0.5, 1)
	end

end

function PlayerZone:TextColor(pvp)
	local faction, FS1, FS2 = UnitFactionGroup("player"), PlayerZoneFrameText1, PlayerZoneFrameText2
		
	if ( pvp == 0 ) then
		FS1:SetTextColor(1, 1, 0)
		FS2:SetTextColor(1, 1, 0)
	elseif ( pvp == 1 and faction == "Alliance" ) then
		FS1:SetTextColor(0, 1, 0)
		FS2:SetTextColor(0, 1, 0)
	elseif ( pvp == 1 and faction == "Horde" ) then
		FS1:SetTextColor(1, 0, 0)
		FS2:SetTextColor(1, 0, 0)
	elseif ( pvp == 2 and faction == "Alliance" ) then
		FS1:SetTextColor(1, 0, 0)
		FS2:SetTextColor(1, 0, 0)
	elseif ( pvp == 2 and faction == "Horde" ) then
		FS1:SetTextColor(0, 1, 0)
		FS2:SetTextColor(0, 1, 0)
	elseif ( pvp == 3 ) then
		FS1:SetTextColor(0, 0.8, 1)
		FS2:SetTextColor(0, 0.8, 1)
	else
		return
	end
	
end

function PlayerZone:SetFrameSize()

	local lF, mF, fS1, fS2, fS3, subZone = PlayerZoneLevelFrame, PlayerZoneFrame, PlayerZoneFrameText1, PlayerZoneFrameText2, PlayerZoneLevelText, GetSubZoneText()
	local l1, l2, l3, lM = fS1:GetWidth(), fS2:GetWidth(), fS3:GetWidth(), 0
	local h1, h2, h3, hM = fS1:GetHeight(), fS2:GetHeight(), fS3:GetHeight(), 0
	
	if ( #subZone == 0 ) then
		hM = h1 + 15
		fS1:SetPoint("CENTER")
		if ( lF:IsShown() ) then
			if ( l3 > l1 ) then
				lM = l3 + 15
			else
				lM = l1 + 15
			end
		else
			lM = l1 + 15
		end
	else
		hM = h1 + h2 + 15
		fS1:SetPoint("TOP", 0, -7)
		fS2:SetPoint("BOTTOM", 0, 7)
		if ( lF:IsShown() ) then
			if ( l1 > l2 ) then
				if ( l1 > l3 ) then
					lM = l1 + 15
				else
					lM = l3 + 15
				end
			elseif ( l1 < l2 ) then
				if ( l2 > l3 ) then
					lM = l2 + 15
				else
					lM = l3 + 15
				end
			end
		else
			if ( l1 > l2 ) then
				lM = l1 + 15
			else
				lM = l2 + 15
			end
		end
	end
	if ( lF:IsShown() ) then fS3:SetPoint("CENTER") end
	mF:SetWidth(lM)
	mF:SetHeight(hM)
	lF:SetHeight(h3 + 10)
	lF:SetWidth(l3 + 15)
	
	-- In entry of Orgrimmar (between Durotar and Strengh valley) there is something that don't let the main frame update correctly.
	-- fixing it temporary with the next code. Have to see why this happen.
	local z, sZ = string.lower(GetZoneText()), string.lower(GetSubZoneText())
		if ( z == "orgrimmar" and sZ == "orgrimmar" ) then
			fS1:SetText(GetZoneText())
			fS1:SetPoint("CENTER")
			fS2:SetText("")
			mF:SetWidth(l1 + 15)
			mF:SetHeight(h1 + 15)
			fS3:SetText(L["Capitale"])
			lF:SetHeight(h3 + 10)
			lF:SetWidth(l3 + 15)
	end
end